==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.md <==
# AwsLicenseManagerLicenseBlending


```text
aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')
```



| Illustration | AwsLicenseManagerLicenseBlending | AwsLicenseManagerLicenseBlendingCard | AwsLicenseManagerLicenseBlendingGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.png) | ![illustration for AwsLicenseManagerLicenseBlending](../../../aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingCard](../../../aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingCard.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingGroup.Local.png) |




## AwsLicenseManagerLicenseBlending

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

## AwsLicenseManagerLicenseBlendingCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

## AwsLicenseManagerLicenseBlendingGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-q3-2021/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.md <==
# AwsLicenseManagerLicenseBlending


```text
aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending
```

```text
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')
```



| Illustration | AwsLicenseManagerLicenseBlending | AwsLicenseManagerLicenseBlendingCard | AwsLicenseManagerLicenseBlendingGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.png) | ![illustration for AwsLicenseManagerLicenseBlending](../../../aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingCard](../../../aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingCard.Local.png) | ![illustration for AwsLicenseManagerLicenseBlendingGroup](../../../aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlendingGroup.Local.png) |




## AwsLicenseManagerLicenseBlending

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlending
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlending('AwsLicenseManagerLicenseBlending', 'Aws License Manager License Blending', 'an optional tech label')
@enduml
```

## AwsLicenseManagerLicenseBlendingCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingCard
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingCard('AwsLicenseManagerLicenseBlendingCard', 'Aws License Manager License Blending Card', 'an optional description')
@enduml
```

## AwsLicenseManagerLicenseBlendingGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsLicenseManagerLicenseBlendingGroup
include('aws-q1-2022/Resource/ManagementGovernance/AwsLicenseManagerLicenseBlending')

' renders the element
AwsLicenseManagerLicenseBlendingGroup('AwsLicenseManagerLicenseBlendingGroup', 'Aws License Manager License Blending Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
